@@ -10,11 +10,8 @@ from .data_model import (CombineArchiveBase, CombineArchive, CombineArchiveConte
                          CombineArchiveContentFormat, CombineArchiveContentFormatPattern)
 from ..archive.io import ArchiveReader
 from ..config import get_config, Config  # noqa: F401
-from ..data_model import Person
 from ..utils.core import flatten_nested_list_of_strings
 from ..warnings import warn, BioSimulatorsWarning
-import dateutil.parser
-import dateutil.tz
 import libcombine
 import os
 import re
@@ -57,9 +54,6 @@ class CombineArchiveWriter(object):
         # instantiate archive
         archive_comb = libcombine.CombineArchive()
 
-        # set metadata about archive
-        self._write_metadata(archive, archive_comb, '.')
-
         # add files to archive
         for i_content, content in enumerate(archive.contents):
             if not archive_comb.addFile(
@@ -72,7 +66,6 @@ class CombineArchiveWriter(object):
                 msg = 'Content element {} could not be added to the archive.'.format(content_id)
                 self.errors.append([msg])
                 raise Exception(msg)
-            self._write_metadata(content, archive_comb, content.location)
 
         # save archive to a file
         if not archive_comb.writeToFile(out_file):
@@ -120,55 +113,6 @@ class CombineArchiveWriter(object):
 
         libcombine.writeOMEXToFile(manifest, filename)
 
-    def _write_metadata(self, obj, archive_comb, filename):
-        """ Write metadata about an archive or a file in an archive
-
-        Args:
-            obj (:obj:`CombineArchiveBase`): archive or file in an archive
-            archive_comb (:obj:`libcombine.CombineArchive`): archive
-            filename (:obj:`str`): path of object with archive
-
-        Raises:
-            :obj:`NotImplementedError`: of the updated date is not defined
-        """
-        desc_comb = libcombine.OmexDescription()
-        desc_comb.setAbout(filename)
-        set_attributes = set()
-
-        if obj.description:
-            set_attributes.add('description')
-            desc_comb.setDescription(obj.description)
-
-        for author in obj.authors:
-            set_attributes.add('authors')
-            creator_comb = libcombine.VCard()
-            if author.given_name:
-                creator_comb.setGivenName(author.given_name)
-            if author.family_name:
-                creator_comb.setFamilyName(author.family_name)
-            desc_comb.addCreator(creator_comb)
-
-        if obj.created:
-            set_attributes.add('created')
-            date_comb = libcombine.Date()
-            date_comb.setDateAsString(obj.created.strftime('%Y-%m-%dT%H:%M:%SZ'))
-            desc_comb.setCreated(date_comb)
-
-        if obj.updated:
-            set_attributes.add('updated')
-            date_comb = libcombine.Date()
-            date_comb.setDateAsString(obj.updated.strftime('%Y-%m-%dT%H:%M:%SZ'))
-            desc_comb.getModified().append(date_comb)
-
-        if set_attributes:
-            if desc_comb.isEmpty():
-                msg = 'libCOMBINE requires additional metadata. Only the following attributes are set:\n  {}'.format(
-                    '\n  '.join(sorted(set_attributes)))
-                self.errors.append([msg])
-                raise ValueError(msg)
-
-            archive_comb.addMetadata(filename, desc_comb)
-
 
 class CombineArchiveReader(object):
     """ Reader for COMBINE/OMEX archives
@@ -239,9 +183,6 @@ class CombineArchiveReader(object):
         # instantiate archive
         archive = CombineArchive()
 
-        # read metadata
-        self._read_metadata(archive_comb, '.', archive)
-
         # read files
         for location in archive_comb.getAllLocations():
             location = location.c_str()
@@ -257,7 +198,6 @@ class CombineArchiveReader(object):
                 format=format,
                 master=file_comb.isSetMaster() and file_comb.getMaster(),
             )
-            self._read_metadata(archive_comb, location, content)
             archive.contents.append(content)
 
         # extract files
@@ -265,8 +205,10 @@ class CombineArchiveReader(object):
 
         # read metadata files skipped by libCOMBINE
         content_locations = set(os.path.relpath(content.location, '.') for content in archive.contents)
+        manifest_contents = self.read_manifest(os.path.join(out_dir, 'manifest.xml'), in_file, config=config)
+
         if include_omex_metadata_files:
-            for manifest_content in self.read_manifest(os.path.join(out_dir, 'manifest.xml'), in_file, config=config):
+            for manifest_content in manifest_contents:
                 if (
                     manifest_content.format
                     and re.match(CombineArchiveContentFormatPattern.OMEX_METADATA.value, manifest_content.format)
@@ -274,6 +216,25 @@ class CombineArchiveReader(object):
                 ):
                     archive.contents.append(manifest_content)
 
+        if config.VALIDATE_OMEX_MANIFESTS:
+            manifest_includes_archive = False
+            for manifest_content in manifest_contents:
+                if os.path.relpath(manifest_content.location, '.') == '.':
+                    if manifest_content.format:
+                        if re.match(CombineArchiveContentFormatPattern.OMEX, manifest_content.format):
+                            manifest_includes_archive = True
+                        else:
+                            msg = 'The format of the archive must be `{}`, not `{}`.'.format(
+                                CombineArchiveContentFormat.OMEX, manifest_content.format)
+                            self.errors.append([msg])
+
+            if not manifest_includes_archive:
+                msg = (
+                    'The manifest does not include its parent COMBINE/OMEX archive. '
+                    'Manifests should include their parent COMBINE/OMEX archives.'
+                )
+                self.warnings.append([msg])
+
         # raise warnings and errors
         if self.warnings:
             warn('COMBINE/OMEX archive may be invalid.\n  ' + flatten_nested_list_of_strings(self.warnings).replace('\n', '\n  '),
@@ -306,7 +267,9 @@ class CombineArchiveReader(object):
                 return []
             else:
                 try:
-                    return CombineArchiveZipReader().run(archive_filename).contents
+                    contents = CombineArchiveZipReader().run(archive_filename).contents
+                    contents.append(CombineArchiveContent(location='.', format=CombineArchiveContentFormat.ZIP))
+                    return contents
                 except ValueError:
                     msg = "`{}` is not a valid zip file.".format(archive_filename)
                     self.errors.append([msg])
@@ -321,7 +284,9 @@ class CombineArchiveReader(object):
         else:
             if errors:
                 try:
-                    return CombineArchiveZipReader().run(archive_filename).contents
+                    contents = CombineArchiveZipReader().run(archive_filename).contents
+                    contents.append(CombineArchiveContent(location='.', format=CombineArchiveContentFormat.ZIP))
+                    return contents
                 except ValueError:
                     msg = "`{}` is not a valid zip file.".format(archive_filename)
                     self.errors.append([msg])
@@ -341,40 +306,9 @@ class CombineArchiveReader(object):
                 content.master = content_comb.getMaster()
 
             contents.append(content)
+
         return contents
 
-    def _read_metadata(self, archive_comb, filename, obj):
-        """ Read metadata about an archive or a file in an archive
-
-        Args:
-            archive_comb (:obj:`libcombine.CombineArchive`): archive
-            filename (:obj:`str`): path to object within archive
-            obj (:obj:`CombineArchiveBase`): object to add metadata to
-        """
-        desc_comb = archive_comb.getMetadataForLocation(filename)
-        if not desc_comb.isEmpty():
-            obj.description = desc_comb.getDescription() or None
-
-            for creator_comb in desc_comb.getCreators():
-                obj.authors.append(Person(
-                    given_name=creator_comb.getGivenName() or None,
-                    family_name=creator_comb.getFamilyName() or None,
-                ))
-
-            created_comb = desc_comb.getCreated().getDateAsString()
-            if created_comb == self.NONE_DATETIME:
-                obj.created = None
-            else:
-                obj.created = dateutil.parser.parse(created_comb)
-
-            obj.updated = None
-            for modified_comb in desc_comb.getModified():
-                updated = dateutil.parser.parse(modified_comb.getDateAsString())
-                if obj.updated:
-                    obj.updated = max(obj.updated, updated)
-                else:
-                    obj.updated = updated
-
 
 class CombineArchiveZipReader(object):
     """ Create a COMBINE/OMEX archive object from a plain zip archive. Set the format of files with
