@@ -202,7 +202,7 @@ class OmexMetaReader(abc.ABC):
 
                 lines[0] = line
 
-                temp_fid, temp_filename = tempfile.mkstemp()
+                temp_fid, temp_filename = tempfile.mkstemp(dir=os.path.dirname(filename))
                 os.close(temp_fid)
                 with open(temp_filename, 'wb') as file:
                     for line in lines:
@@ -828,8 +828,11 @@ class BiosimulationsOmexMetaWriter(OmexMetaWriter):
                                     object,
                                     namespaces['foaf'].accountName,
                                     rdflib.term.URIRef(value['uri']
+                                                       .replace('http://identifiers.org/orcid:',
+                                                                'https://orcid.org/')
                                                        .replace('https://identifiers.org/orcid:',
-                                                                'https://orcid.org/'))
+                                                                'https://orcid.org/')
+                                                       )
                                 ))
 
                             if value.get('label', None) is not None:
