@@ -70,9 +70,11 @@ class ModelLanguage(str, enum.Enum):
     MASS = 'urn:sedml:language:mass'
     MorpheusML = 'urn:sedml:language:morpheusml'
     NeuroML = 'urn:sedml:language:neuroml'
+    NMODL = 'urn:sedml:language:nmodl'
     pharmML = 'urn:sedml:language:pharmml'
     RBA = 'urn:sedml:language:rba'
     SBML = 'urn:sedml:language:sbml'
+    SLI = 'urn:sedml:language:sli'
     Smoldyn = 'urn:sedml:language:smoldyn'
     VCML = 'urn:sedml:language:vcml'
     XPP = 'urn:sedml:language:xpp'
@@ -84,16 +86,20 @@ class ModelLanguagePattern(str, enum.Enum):
     BNGL = r'^urn:sedml:language:bngl(\.|$)'
     CellML = r'^urn:sedml:language:cellml(\.\d+_\d+)?$'
     CopasiML = r'^urn:sedml:language:copasiml(\.|$)'
+    GENESIS = r'^urn:sedml:language:genesis(\.|$)'
     GINML = r'^urn:sedml:language:ginml(\.|$)'
     HOC = r'^urn:sedml:language:hoc(\.|$)'
     Kappa = r'^urn:sedml:language:kappa(\.|$)'
     LEMS = r'^urn:sedml:language:lems(\.|$)'
     MASS = r'^urn:sedml:language:mass(\.|$)'
     MorpheusML = r'^urn:sedml:language:morpheusml(\.|$)'
+    NCS = r'^urn:sedml:language:ncs(\.|$)'
     NeuroML = r'^urn:sedml:language:neuroml(\.version-\d+_\d+_\d+\.level\-\d+)?$'
+    NMODL = r'^urn:sedml:language:nmodl(\.|$)'
     pharmML = r'^urn:sedml:language:pharmml(\.|$)'
     RBA = r'^urn:sedml:language:rba(\.|$)'
     SBML = r'^urn:sedml:language:sbml(\.level\-\d+\.version\-\d+)?$'
+    SLI = r'^urn:sedml:language:sli(\.|$)'
     Smoldyn = r'^urn:sedml:language:smoldyn(\.|$)'
     VCML = r'^urn:sedml:language:vcml(\.|$)'
     XPP = r'^urn:sedml:language:xpp(\.|$)'
@@ -105,16 +111,20 @@ class ModelLanguageEdamId(str, enum.Enum):
     BNGL = 'format_3972'
     CellML = 'format_3240'
     CopasiML = 'format_9003'
+    GENESIS = 'format_9056'
     GINML = 'format_9009'
     HOC = 'format_9005'
     Kappa = 'format_9006'
     LEMS = 'format_9004'
     MASS = 'format_9011'
     MorpheusML = 'format_9002'
+    NCS = 'format_9057'
     NeuroML = 'format_3971'
+    NMODL = 'format_9052'
     pharmML = 'format_9007'
     RBA = 'format_9012'
     SBML = 'format_2585'
+    SLI = 'format_9054'
     Smoldyn = 'format_9001'
     VCML = 'format_9000'
     XPP = 'format_9010'
@@ -1255,7 +1265,7 @@ class FunctionalRange(Range, Calculation):
         name (:obj:`str`): name
         range (:obj:`Range`): range
         variables (:obj:`list` of :obj:`Variable`): variables
-        parameters (:obj:`list` of :obj:`Parameter`): variables
+        parameters (:obj:`list` of :obj:`Parameter`): parameters
         math (:obj:`str`): mathematical expression
     """
 
@@ -1266,7 +1276,7 @@ class FunctionalRange(Range, Calculation):
             name (:obj:`str`, optional): name
             range (:obj:`Range`, optional): range
             variables (:obj:`list` of :obj:`Variable`, optional): variables
-            parameters (:obj:`list` of :obj:`Parameter`, optional): variables
+            parameters (:obj:`list` of :obj:`Parameter`, optional): parameters
             math (:obj:`str`, optional): mathematical expression
         """
         Range.__init__(self, id=id, name=name)
@@ -1307,7 +1317,7 @@ class DataGenerator(Calculation, SedIdGroupMixin):
         id (:obj:`str`): id
         name (:obj:`str`): name
         variables (:obj:`list` of :obj:`Variable`): variables
-        parameters (:obj:`list` of :obj:`Parameter`): variables
+        parameters (:obj:`list` of :obj:`Parameter`): parameters
         math (:obj:`str`): mathematical expression
     """
 
@@ -1317,7 +1327,7 @@ class DataGenerator(Calculation, SedIdGroupMixin):
             id (:obj:`str`, optional): id
             name (:obj:`str`, optional): name
             variables (:obj:`list` of :obj:`Variable`, optional): variables
-            parameters (:obj:`list` of :obj:`Parameter`, optional): variables
+            parameters (:obj:`list` of :obj:`Parameter`, optional): parameters
             math (:obj:`str`, optional): mathematical expression
         """
         SedIdGroupMixin.__init__(self, id=id, name=name)
