@@ -215,7 +215,7 @@ class ValidationTestCase(unittest.TestCase):
             with self.assertRaisesRegex(ValueError, 'other error'):
                 validate(archive, self.tmp_dir)
 
-        def side_effect(self, filename, validate_models_with_languages=False):
+        def side_effect(self, filename, validate_models_with_languages=False, config=None):
             self.warnings = [['my warning']]
         with mock.patch.object(SedmlSimulationReader, 'run', side_effect):
             errors, warnings = validate(archive, self.tmp_dir)
@@ -224,6 +224,19 @@ class ValidationTestCase(unittest.TestCase):
         self.assertIn('may be invalid', flatten_nested_list_of_strings(warnings))
         self.assertIn('my warning', flatten_nested_list_of_strings(warnings))
 
+    def test_manifest_in_manifest(self):
+        out_dir = os.path.join(self.tmp_dir, 'out')
+        archive = CombineArchiveReader().run(os.path.join(os.path.dirname(__file__), '..', 'fixtures', 'manifest-in-manifest.omex'), out_dir)
+        errors, warnings = validate(archive, out_dir)
+        self.assertEqual(errors, [])
+        self.assertIn('manifests should not contain content entries for themselves', flatten_nested_list_of_strings(warnings))
+
+        out_dir = os.path.join(self.tmp_dir, 'out')
+        archive = CombineArchiveReader().run(os.path.join(os.path.dirname(__file__), '..', 'fixtures', 'multiple-manifests.omex'), out_dir)
+        errors, warnings = validate(archive, out_dir)
+        self.assertEqual(errors, [])
+        self.assertIn('manifests should not contain content entries for themselves', flatten_nested_list_of_strings(warnings))
+
     def test_no_validation(self):
         archive_dirname = os.path.join(self.tmp_dir, 'archive')
         os.mkdir(archive_dirname)
